@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -151,6 +151,7 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "CN", "\u127b\u12ed\u1293" },
             { "CO", "\u12ae\u120e\u121d\u1265\u12eb" },
             { "CP", "\u12f0\u1234\u1275 \u12ad\u120a\u1350\u122d\u1276\u1295" },
+            { "CQ", "\u1233\u122d\u12ad" },
             { "CR", "\u12ae\u1235\u1273 \u122a\u12ab" },
             { "CU", "\u12a9\u1263" },
             { "CV", "\u12ac\u1355 \u1268\u122d\u12f0" },
@@ -212,7 +213,6 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "IL", "\u12a5\u1235\u122b\u12a4\u120d" },
             { "IM", "\u12a3\u12ed\u120d \u12a6\u134d \u121b\u1295" },
             { "IN", "\u1205\u1295\u12f2" },
-            { "IO", "\u1265\u122a\u1323\u1295\u12eb\u12ca \u1205\u1295\u12f3\u12ca \u12cd\u1245\u12eb\u1296\u1235 \u130d\u12dd\u12a3\u1275" },
             { "IQ", "\u12d2\u122b\u1255" },
             { "IR", "\u12a2\u122b\u1295" },
             { "IS", "\u12a3\u12ed\u1235\u120b\u1295\u12f5" },
@@ -545,6 +545,7 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "alt", "\u12f0\u1261\u1263\u12ca \u12a3\u120d\u1273\u12ed" },
             { "ann", "\u12a6\u1266\u120e" },
             { "anp", "\u12a3\u1295\u1302\u12ab" },
+            { "apc", "\u120c\u126b\u1295\u1272\u1293\u12ca \u12d3\u1228\u1265" },
             { "arn", "\u121b\u1351\u127a" },
             { "arp", "\u12a3\u122b\u1353\u1206" },
             { "ars", "\u1293\u1305\u12f2 \u12d3\u1228\u1265\u129b" },
@@ -655,6 +656,7 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "lij", "\u120a\u1309\u122d\u129b" },
             { "lil", "\u120a\u1209\u1275" },
             { "lkt", "\u120b\u12ae\u1273" },
+            { "lmo", "\u120e\u121d\u1263\u122d\u12f5\u129b" },
             { "lou", "\u12ad\u122d\u12ee\u120d \u1209\u12ca\u12dd\u12eb\u1293" },
             { "loz", "\u120e\u12da" },
             { "lrc", "\u1230\u121c\u1293\u12ca \u1209\u122a" },
@@ -713,9 +715,11 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "pis", "\u1352\u1302\u1295" },
             { "pqm", "\u121b\u120a\u1232\u1275-\u1353\u1233\u121b\u12b3\u12f2" },
             { "prg", "\u1355\u1229\u1235\u129b" },
+            { "raj", "\u122b\u1303\u1235\u1273\u1292" },
             { "rap", "\u122b\u1353\u1291\u12ed" },
             { "rar", "\u122b\u122e\u1276\u1295\u130b\u1295\u129b" },
             { "rhg", "\u122e\u1202\u1295\u130d\u12eb" },
+            { "rif", "\u122a\u134d\u129b" },
             { "rof", "\u122e\u121d\u1266" },
             { "rup", "\u12a3\u1229\u121b\u1295\u129b" },
             { "rwk", "\u122d\u12cb" },
@@ -783,23 +787,12 @@ public class LocaleNames_ti extends OpenListResourceBundle {
             { "Zsye", "\u12a2\u121e\u1302" },
             { "Zsym", "\u121d\u120d\u12ad\u1273\u1275" },
             { "Zxxx", "\u12d8\u12ed\u1270\u133b\u1215\u1348" },
-            { "de_CH", "\u1300\u122d\u1218\u1295 (\u1235\u12ca\u12d8\u122d\u120b\u1295\u12f5)" },
-            { "en_AU", "\u12a5\u1295\u130d\u120a\u12dd\u129b (\u12a3\u12cd\u1235\u1275\u122b\u120d\u12eb)" },
-            { "en_CA", "\u12a5\u1295\u130d\u120a\u12dd\u129b (\u12ab\u1293\u12f3)" },
-            { "en_GB", "\u12a5\u1295\u130d\u120a\u12dd\u129b (\u1265\u122a\u1323\u1295\u12eb)" },
             { "en_US", "\u12a5\u1295\u130d\u120a\u12dd\u129b (\u1215\u1261\u122b\u1275 \u1218\u1295\u130d\u1235\u1273\u1275)" },
-            { "es_ES", "\u1235\u1333\u1295\u129b (\u1235\u1333\u129b)" },
-            { "es_MX", "\u1235\u1333\u1295\u129b (\u121c\u12ad\u1232\u12ae)" },
             { "fa_AF", "\u12f3\u122a" },
-            { "fr_CA", "\u1348\u1228\u1295\u1233\u12ed\u129b (\u12ab\u1293\u12f3)" },
-            { "fr_CH", "\u1348\u1228\u1295\u1233\u12ed\u129b (\u1235\u12ca\u12d8\u122d\u120b\u1295\u12f5)" },
             { "nl_BE", "\u134d\u120b\u121a\u123d" },
-            { "pt_BR", "\u1356\u122d\u1271\u130a\u12dd\u129b (\u1265\u122b\u12da\u120d)" },
-            { "pt_PT", "\u1356\u122d\u1271\u130a\u12dd\u129b (\u1356\u122d\u1271\u130b\u120d)" },
             { "ro_MD", "\u121e\u120d\u12f6\u1268\u129b" },
             { "sw_CD", "\u1235\u12cb\u1202\u120a (\u12ae\u1295\u130e)" },
             { "ar_001", "\u12d8\u1218\u1293\u12ca \u121d\u12f1\u1265 \u12d3\u1228\u1265" },
-            { "es_419", "\u1235\u1333\u1295\u129b (\u120b\u1272\u1295 \u12a3\u1218\u122a\u12ab)" },
             { "key.ca", "\u12d3\u12cd\u12f0-\u12a3\u12cb\u122d\u1215" },
             { "key.cf", "\u1245\u122d\u133a \u1263\u1324\u122b" },
             { "key.cu", "\u1263\u1324\u122b" },
